User prompt
Let the player follow the mouse arrow after clicking on the player.
User prompt
don't push player from cursor after mouse button clicked on it
User prompt
Regenerate a hexagon maze in exact same position of the image background1.
Code edit (1 edits merged)
Please save this source code
User prompt
Remove all walls from the game
User prompt
Make the middle of each wall1 2 3 4 in the middle of there sides
User prompt
Make the center of each wall in the middle of its side
User prompt
Center the walls each side
User prompt
Make each wall in the middle of its side
User prompt
Set each wall with same size of its side of the screen outlines.
User prompt
Make all 4 walls taller to the corners
Code edit (3 edits merged)
Please save this source code
User prompt
make the bottom wall between the vertical wall from the bottom
User prompt
Make the bottom wall up a bit to the bottom line
Code edit (1 edits merged)
Please save this source code
User prompt
make it down again but a bit not ,uch
User prompt
Move the background1 image little bit up
User prompt
Make the top wall thin a bit vertically.
User prompt
make it thin a bit
User prompt
Make the wall of the top thick vertically.
User prompt
make same size of top wall ass the bottom wall
User prompt
Move the bottom wall a bit to the right
User prompt
Make the wall of the top and bottom larger horizontal to the corners
User prompt
move wall2 to the middle
User prompt
move it to the midle
/**** * Classes ****/ // Class for the player character var Player = Container.expand(function () { var self = Container.call(this); self.interactive = true; // Make the player interactive var playerGraphics = self.attachAsset('player', { anchorX: 1.9, anchorY: 1.9 }); self.dragging = false; // Add a variable to track if the player is being dragged }); // Class for the wall var Wall = Container.expand(function () { var self = Container.call(this); var wallGraphics = self.attachAsset('wall1', { anchorX: 0.05, anchorY: 0.05 }); }); /**** * Initialize Game ****/ var game = new LK.Game({ backgroundColor: 0x000000 //Init game with black background }); /**** * Game Code ****/ // Add background to the game var background = game.attachAsset('Background1', { anchorX: 0.5, anchorY: 1, x: 2048 / 2, y: 2732 - 50, // Move the background down by 80 pixels scaleX: 2048 / 1000, scaleY: (2732 - LK.gui.top.height - 200) / 1000 // Scale down from the top by 200 pixels }); // Set level to 1 game.level = 1; // Initialize player var player = new Player(); player.x = 2048; player.y = 2732; player.interactive = true; game.addChild(player); // Initialize wall1 var wall1 = new Wall(); wall1.x = 2048 - wall1.width; // Move wall1 to the right edge of the screen // Initialize wall2 first to get its height var wall2 = new Wall(); wall2.x = 100; // Move wall2 a little bit more to the right wall2.y = 0; // Position wall2 at the top of the screen wall2.width = 100; // Make wall2 thinner wall2.height = 200; // Keep wall2's height the same game.addChild(wall2); // Now we can use wall2.height wall1.y = wall2.height; // Position wall1 below the top wall wall1.width = 100; // Make wall1 thinner vertically wall1.height = 2732; // Make wall1 as tall as the screen game.addChild(wall1); // Initialize wall3 on the left side of the screen var wall3 = new Wall(); wall3.x = 0; // Position wall3 at the left edge of the screen wall3.y = wall2.height; // Position wall3 below the top wall wall3.width = 100; // Make wall3 thinner wall3.height = 2732; // Keep wall3's height the same game.addChild(wall3); // Initialize wall4 at the bottom of the screen var wall4 = new Wall(); wall4.x = wall1.width; // Move wall4 to the right edge of wall1 wall4.y = 2732 - wall4.height; // Position wall4 at the bottom of the screen wall4.width = 2048 - wall1.width - wall3.width; // Make wall4 as wide as the screen minus the widths of wall1 and wall3 wall4.height = 200; // Make wall4 taller horizontally game.addChild(wall4); // Initialize wall2 var wall2 = new Wall(); wall2.x = 100; // Move wall2 a bit to the right wall2.y = 0; // Position wall2 at the top of the screen wall2.width = 2048; // Make wall2 as wide as the screen wall2.height = 200; // Decrease the thickness of the top wall vertically game.addChild(wall2); // Add Level 1 text on the top right var levelText = new Text2('Level 1', { size: 100, fill: 0xFFFFFF, font: "'Time new roman'" }); levelText.anchor.set(1, 0); // Sets anchor to the top right edge of the text. LK.gui.topRight.addChild(levelText); // Handle player movement // Import tween plugin var dragNode = null; game.down = function (x, y, obj) { dragNode = player; }; game.move = function (x, y, obj) { if (dragNode) { dragNode.x = x - dragNode.width / 10; dragNode.y = y - dragNode.height / 10; } }; game.up = function (x, y, obj) { dragNode = null; };
===================================================================
--- original.js
+++ change.js
@@ -71,11 +71,11 @@
wall3.height = 2732; // Keep wall3's height the same
game.addChild(wall3);
// Initialize wall4 at the bottom of the screen
var wall4 = new Wall();
-wall4.x = 100; // Move wall4 a bit to the right
-wall4.y = 2732 - wall4.height - 100; // Position wall4 a bit up from the bottom of the screen
-wall4.width = 2048; // Make wall4 as wide as the screen
+wall4.x = wall1.width; // Move wall4 to the right edge of wall1
+wall4.y = 2732 - wall4.height; // Position wall4 at the bottom of the screen
+wall4.width = 2048 - wall1.width - wall3.width; // Make wall4 as wide as the screen minus the widths of wall1 and wall3
wall4.height = 200; // Make wall4 taller horizontally
game.addChild(wall4);
// Initialize wall2
var wall2 = new Wall();